"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const zlib_1 = require("zlib");
exports.createEncodingCompressTransform = (encoding, options) => () => {
    switch (encoding) {
        case "br":
            return zlib_1.createBrotliCompress(options);
        case "deflate":
            return zlib_1.createDeflate(options);
        case "gzip":
            return zlib_1.createGzip(options);
        case "compress":
        case "identity":
            throw new Error("unsupported encoding");
    }
};
exports.createEncodingDecompressTransform = (encoding, options) => () => {
    switch (encoding) {
        case "br":
            return zlib_1.createBrotliDecompress(options);
        case "deflate":
            return zlib_1.createInflate(options);
        case "gzip":
            return zlib_1.createGunzip(options);
        case "compress":
        case "identity":
            throw new Error("unsupported encoding");
    }
};
exports.supportedEncodings = [
    "gzip",
    "deflate",
    "br",
];
exports.getFirstSupportedEncoding = (acceptedEncodings) => acceptedEncodings.find(encoding => exports.supportedEncodings.includes(encoding));
//# sourceMappingURL=httpContentEncoding.js.map